# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/builds/build.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.user_application.common.v0 import resources_pb2 as qwak_dot_user__application_dot_common_dot_v0_dot_resources__pb2
from _qwak_proto.qwak.fitness_service import fitness_pb2 as qwak_dot_fitness__service_dot_fitness__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17qwak/builds/build.proto\x12\x18qwak.builds.orchestrator\x1a/qwak/user_application/common/v0/resources.proto\x1a\"qwak/fitness_service/fitness.proto\"\xec\x05\n\x0fRemoteBuildSpec\x12\x43\n\x10\x62uild_properties\x18\x01 \x01(\x0b\x32).qwak.builds.orchestrator.BuildProperties\x12\x35\n\tbuild_env\x18\x02 \x01(\x0b\x32\".qwak.builds.orchestrator.BuildEnv\x12\x43\n\rcpu_resources\x18\x03 \x01(\x0b\x32&.qwak.builds.orchestrator.CpuResourcesB\x02\x18\x01H\x00\x12\x43\n\rgpu_resources\x18\x07 \x01(\x0b\x32&.qwak.builds.orchestrator.GpuResourcesB\x02\x18\x01H\x00\x12\x62\n\x1c\x63lient_pod_compute_resources\x18\r \x01(\x0b\x32:.qwak.user_application.common.v0.ClientPodComputeResourcesH\x00\x12\x0f\n\x07verbose\x18\x04 \x01(\x05\x12\x17\n\x0f\x62uild_code_path\x18\x05 \x01(\t\x12\x14\n\x0c\x62uild_config\x18\x06 \x01(\t\x12\x15\n\rbuild_v1_flag\x18\x08 \x01(\x08\x12H\n\x13\x62uild_properties_v1\x18\t \x01(\x0b\x32+.qwak.builds.orchestrator.BuildPropertiesV1\x12\x13\n\x0b\x62uild_steps\x18\n \x03(\t\x12\x16\n\x0e\x65nvironment_id\x18\x0b \x01(\t\x12\x13\n\x0bsdk_version\x18\x0c \x01(\t\x12=\n\x0fpurchase_option\x18\x0e \x01(\x0e\x32$.qwak.fitness.service.PurchaseOption\x12\x1c\n\x14\x62uild_destined_image\x18\x0f \x01(\t\x12\"\n\x1aprovision_instance_timeout\x18\x10 \x01(\x05\x42\x0b\n\tResources\"g\n\x11\x42uildPropertiesV1\x12\x18\n\x10\x62uild_config_url\x18\x01 \x01(\t\x12\x1a\n\x12qwak_sdk_wheel_url\x18\x02 \x01(\t\x12\x1c\n\x14qwak_sdk_version_url\x18\x03 \x01(\t\"\xa6\x01\n\x0f\x42uildProperties\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x02 \x01(\t\x12\x10\n\x08model_id\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x39\n\tmodel_uri\x18\x05 \x01(\x0b\x32&.qwak.builds.orchestrator.ModelUriSpec\x12\x16\n\x0egpu_compatible\x18\x06 \x01(\x08\"\xb2\x01\n\x0cModelUriSpec\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x12\n\ngit_branch\x18\x02 \x01(\t\x12\x17\n\x0fgit_credentials\x18\x03 \x01(\t\x12\x1e\n\x16git_credentials_secret\x18\x04 \x01(\t\x12\x11\n\tcommit_id\x18\x05 \x01(\t\x12\x10\n\x08main_dir\x18\x06 \x01(\t\x12#\n\x1b\x64\x65pendency_required_folders\x18\x07 \x03(\t\"|\n\x08\x42uildEnv\x12\x37\n\ndocker_env\x18\x01 \x01(\x0b\x32#.qwak.builds.orchestrator.DockerEnv\x12\x37\n\npython_env\x18\x02 \x01(\x0b\x32#.qwak.builds.orchestrator.PythonEnv\"\x8a\x01\n\tDockerEnv\x12\x12\n\nbase_image\x18\x01 \x01(\t\x12\x10\n\x08\x65nv_vars\x18\x02 \x03(\t\x12\x10\n\x08no_cache\x18\x03 \x01(\x08\x12\x1c\n\x14\x61ssumed_iam_role_arn\x18\x04 \x01(\t\x12\'\n\x1fservice_account_key_secret_name\x18\x05 \x01(\t\"|\n\tPythonEnv\x12\x17\n\x0fgit_credentials\x18\x01 \x01(\t\x12\x1e\n\x16git_credentials_secret\x18\x02 \x01(\t\x12\x18\n\x10qwak_sdk_version\x18\x03 \x01(\t\x12\x1c\n\x14qwak_sdk_extra_index\x18\x04 \x01(\t\"n\n\x0c\x43puResources\x12\x0b\n\x03\x63pu\x18\x01 \x01(\x02\x12\x15\n\rmemory_amount\x18\x02 \x01(\x05\x12:\n\x0cmemory_units\x18\x03 \x01(\x0e\x32$.qwak.builds.orchestrator.MemoryUnit\"W\n\x0cGpuResources\x12\x33\n\x08gpu_type\x18\x01 \x01(\x0e\x32!.qwak.builds.orchestrator.GpuType\x12\x12\n\ngpu_amount\x18\x02 \x01(\x05\"\x91\x01\n\x13\x44\x61taTableDefinition\x12?\n\x07\x63olumns\x18\x01 \x03(\x0b\x32..qwak.builds.orchestrator.DataColumnDefinition\x12\x39\n\x0b\x64\x61ta_format\x18\x02 \x01(\x0b\x32$.qwak.builds.orchestrator.DataFormat\"\\\n\x14\x44\x61taColumnDefinition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x36\n\x04type\x18\x02 \x01(\x0e\x32(.qwak.builds.orchestrator.DataColumnType\"J\n\nDataFormat\x12\x32\n\x03\x63sv\x18\x01 \x01(\x0b\x32#.qwak.builds.orchestrator.CsvFormatH\x00\x42\x08\n\x06\x66ormat\"G\n\tCsvFormat\x12\x11\n\tdelimiter\x18\x01 \x01(\t\x12\x12\n\nquote_char\x18\x02 \x01(\t\x12\x13\n\x0b\x65scape_char\x18\x03 \x01(\t\"\xa5\x01\n\x0e\x42uildInitiator\x12<\n\x04user\x18\x01 \x01(\x0b\x32,.qwak.builds.orchestrator.UserBuildInitiatorH\x00\x12H\n\nautomation\x18\x02 \x01(\x0b\x32\x32.qwak.builds.orchestrator.AutomationBuildInitiatorH\x00\x42\x0b\n\tInitiator\"\x14\n\x12UserBuildInitiator\"`\n\x18\x41utomationBuildInitiator\x12\x15\n\rautomation_id\x18\x01 \x01(\t\x12\x14\n\x0c\x65xecution_id\x18\x02 \x01(\t\x12\x17\n\x0f\x61utomation_name\x18\x03 \x01(\t*7\n\nMemoryUnit\x12\x17\n\x13UNKNOWN_MEMORY_UNIT\x10\x00\x12\x07\n\x03MIB\x10\x01\x12\x07\n\x03GIB\x10\x02*\x8c\x02\n\x07GpuType\x12\x0b\n\x07INVALID\x10\x00\x12\x0e\n\nNVIDIA_K80\x10\x01\x12\x0f\n\x0bNVIDIA_V100\x10\x02\x12\x0f\n\x0bNVIDIA_A100\x10\x03\x12\r\n\tNVIDIA_T4\x10\x04\x12\x0f\n\x0bNVIDIA_A10G\x10\x05\x12\r\n\tNVIDIA_L4\x10\x06\x12\x14\n\x10NVIDIA_T4_1_4_15\x10\x07\x12\x14\n\x10NVIDIA_T4_1_8_30\x10\x08\x12\x15\n\x11NVIDIA_T4_1_16_60\x10\t\x12\x1e\n\x1aNVIDIA_A100_80GB_8_96_1360\x10\n\x12\x16\n\x12NVIDIA_V100_1_8_52\x10\x0b\x12\x18\n\x14NVIDIA_V100_4_32_208\x10\x0c*d\n\x0e\x44\x61taColumnType\x12\x17\n\x13INVALID_COLUMN_TYPE\x10\x00\x12\n\n\x06OBJECT\x10\x01\x12\x07\n\x03INT\x10\x02\x12\t\n\x05\x46LOAT\x10\x03\x12\x0b\n\x07\x42OOLEAN\x10\x04\x12\x0c\n\x08\x44\x41TETIME\x10\x05*K\n\x13\x42\x61seDockerImageType\x12\"\n\x1eUNKNOWN_BASE_DOCKER_IMAGE_TYPE\x10\x00\x12\x07\n\x03\x43PU\x10\x01\x12\x07\n\x03GPU\x10\x02\x42\'\n#com.qwak.ai.builds.orchestrator.apiP\x01\x62\x06proto3')

_MEMORYUNIT = DESCRIPTOR.enum_types_by_name['MemoryUnit']
MemoryUnit = enum_type_wrapper.EnumTypeWrapper(_MEMORYUNIT)
_GPUTYPE = DESCRIPTOR.enum_types_by_name['GpuType']
GpuType = enum_type_wrapper.EnumTypeWrapper(_GPUTYPE)
_DATACOLUMNTYPE = DESCRIPTOR.enum_types_by_name['DataColumnType']
DataColumnType = enum_type_wrapper.EnumTypeWrapper(_DATACOLUMNTYPE)
_BASEDOCKERIMAGETYPE = DESCRIPTOR.enum_types_by_name['BaseDockerImageType']
BaseDockerImageType = enum_type_wrapper.EnumTypeWrapper(_BASEDOCKERIMAGETYPE)
UNKNOWN_MEMORY_UNIT = 0
MIB = 1
GIB = 2
INVALID = 0
NVIDIA_K80 = 1
NVIDIA_V100 = 2
NVIDIA_A100 = 3
NVIDIA_T4 = 4
NVIDIA_A10G = 5
NVIDIA_L4 = 6
NVIDIA_T4_1_4_15 = 7
NVIDIA_T4_1_8_30 = 8
NVIDIA_T4_1_16_60 = 9
NVIDIA_A100_80GB_8_96_1360 = 10
NVIDIA_V100_1_8_52 = 11
NVIDIA_V100_4_32_208 = 12
INVALID_COLUMN_TYPE = 0
OBJECT = 1
INT = 2
FLOAT = 3
BOOLEAN = 4
DATETIME = 5
UNKNOWN_BASE_DOCKER_IMAGE_TYPE = 0
CPU = 1
GPU = 2


_REMOTEBUILDSPEC = DESCRIPTOR.message_types_by_name['RemoteBuildSpec']
_BUILDPROPERTIESV1 = DESCRIPTOR.message_types_by_name['BuildPropertiesV1']
_BUILDPROPERTIES = DESCRIPTOR.message_types_by_name['BuildProperties']
_MODELURISPEC = DESCRIPTOR.message_types_by_name['ModelUriSpec']
_BUILDENV = DESCRIPTOR.message_types_by_name['BuildEnv']
_DOCKERENV = DESCRIPTOR.message_types_by_name['DockerEnv']
_PYTHONENV = DESCRIPTOR.message_types_by_name['PythonEnv']
_CPURESOURCES = DESCRIPTOR.message_types_by_name['CpuResources']
_GPURESOURCES = DESCRIPTOR.message_types_by_name['GpuResources']
_DATATABLEDEFINITION = DESCRIPTOR.message_types_by_name['DataTableDefinition']
_DATACOLUMNDEFINITION = DESCRIPTOR.message_types_by_name['DataColumnDefinition']
_DATAFORMAT = DESCRIPTOR.message_types_by_name['DataFormat']
_CSVFORMAT = DESCRIPTOR.message_types_by_name['CsvFormat']
_BUILDINITIATOR = DESCRIPTOR.message_types_by_name['BuildInitiator']
_USERBUILDINITIATOR = DESCRIPTOR.message_types_by_name['UserBuildInitiator']
_AUTOMATIONBUILDINITIATOR = DESCRIPTOR.message_types_by_name['AutomationBuildInitiator']
RemoteBuildSpec = _reflection.GeneratedProtocolMessageType('RemoteBuildSpec', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEBUILDSPEC,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.RemoteBuildSpec)
  })
_sym_db.RegisterMessage(RemoteBuildSpec)

BuildPropertiesV1 = _reflection.GeneratedProtocolMessageType('BuildPropertiesV1', (_message.Message,), {
  'DESCRIPTOR' : _BUILDPROPERTIESV1,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildPropertiesV1)
  })
_sym_db.RegisterMessage(BuildPropertiesV1)

BuildProperties = _reflection.GeneratedProtocolMessageType('BuildProperties', (_message.Message,), {
  'DESCRIPTOR' : _BUILDPROPERTIES,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildProperties)
  })
_sym_db.RegisterMessage(BuildProperties)

ModelUriSpec = _reflection.GeneratedProtocolMessageType('ModelUriSpec', (_message.Message,), {
  'DESCRIPTOR' : _MODELURISPEC,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.ModelUriSpec)
  })
_sym_db.RegisterMessage(ModelUriSpec)

BuildEnv = _reflection.GeneratedProtocolMessageType('BuildEnv', (_message.Message,), {
  'DESCRIPTOR' : _BUILDENV,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildEnv)
  })
_sym_db.RegisterMessage(BuildEnv)

DockerEnv = _reflection.GeneratedProtocolMessageType('DockerEnv', (_message.Message,), {
  'DESCRIPTOR' : _DOCKERENV,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.DockerEnv)
  })
_sym_db.RegisterMessage(DockerEnv)

PythonEnv = _reflection.GeneratedProtocolMessageType('PythonEnv', (_message.Message,), {
  'DESCRIPTOR' : _PYTHONENV,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.PythonEnv)
  })
_sym_db.RegisterMessage(PythonEnv)

CpuResources = _reflection.GeneratedProtocolMessageType('CpuResources', (_message.Message,), {
  'DESCRIPTOR' : _CPURESOURCES,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.CpuResources)
  })
_sym_db.RegisterMessage(CpuResources)

GpuResources = _reflection.GeneratedProtocolMessageType('GpuResources', (_message.Message,), {
  'DESCRIPTOR' : _GPURESOURCES,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.GpuResources)
  })
_sym_db.RegisterMessage(GpuResources)

DataTableDefinition = _reflection.GeneratedProtocolMessageType('DataTableDefinition', (_message.Message,), {
  'DESCRIPTOR' : _DATATABLEDEFINITION,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.DataTableDefinition)
  })
_sym_db.RegisterMessage(DataTableDefinition)

DataColumnDefinition = _reflection.GeneratedProtocolMessageType('DataColumnDefinition', (_message.Message,), {
  'DESCRIPTOR' : _DATACOLUMNDEFINITION,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.DataColumnDefinition)
  })
_sym_db.RegisterMessage(DataColumnDefinition)

DataFormat = _reflection.GeneratedProtocolMessageType('DataFormat', (_message.Message,), {
  'DESCRIPTOR' : _DATAFORMAT,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.DataFormat)
  })
_sym_db.RegisterMessage(DataFormat)

CsvFormat = _reflection.GeneratedProtocolMessageType('CsvFormat', (_message.Message,), {
  'DESCRIPTOR' : _CSVFORMAT,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.CsvFormat)
  })
_sym_db.RegisterMessage(CsvFormat)

BuildInitiator = _reflection.GeneratedProtocolMessageType('BuildInitiator', (_message.Message,), {
  'DESCRIPTOR' : _BUILDINITIATOR,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.BuildInitiator)
  })
_sym_db.RegisterMessage(BuildInitiator)

UserBuildInitiator = _reflection.GeneratedProtocolMessageType('UserBuildInitiator', (_message.Message,), {
  'DESCRIPTOR' : _USERBUILDINITIATOR,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.UserBuildInitiator)
  })
_sym_db.RegisterMessage(UserBuildInitiator)

AutomationBuildInitiator = _reflection.GeneratedProtocolMessageType('AutomationBuildInitiator', (_message.Message,), {
  'DESCRIPTOR' : _AUTOMATIONBUILDINITIATOR,
  '__module__' : 'qwak.builds.build_pb2'
  # @@protoc_insertion_point(class_scope:qwak.builds.orchestrator.AutomationBuildInitiator)
  })
_sym_db.RegisterMessage(AutomationBuildInitiator)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.builds.orchestrator.apiP\001'
  _REMOTEBUILDSPEC.fields_by_name['cpu_resources']._options = None
  _REMOTEBUILDSPEC.fields_by_name['cpu_resources']._serialized_options = b'\030\001'
  _REMOTEBUILDSPEC.fields_by_name['gpu_resources']._options = None
  _REMOTEBUILDSPEC.fields_by_name['gpu_resources']._serialized_options = b'\030\001'
  _MEMORYUNIT._serialized_start=2617
  _MEMORYUNIT._serialized_end=2672
  _GPUTYPE._serialized_start=2675
  _GPUTYPE._serialized_end=2943
  _DATACOLUMNTYPE._serialized_start=2945
  _DATACOLUMNTYPE._serialized_end=3045
  _BASEDOCKERIMAGETYPE._serialized_start=3047
  _BASEDOCKERIMAGETYPE._serialized_end=3122
  _REMOTEBUILDSPEC._serialized_start=139
  _REMOTEBUILDSPEC._serialized_end=887
  _BUILDPROPERTIESV1._serialized_start=889
  _BUILDPROPERTIESV1._serialized_end=992
  _BUILDPROPERTIES._serialized_start=995
  _BUILDPROPERTIES._serialized_end=1161
  _MODELURISPEC._serialized_start=1164
  _MODELURISPEC._serialized_end=1342
  _BUILDENV._serialized_start=1344
  _BUILDENV._serialized_end=1468
  _DOCKERENV._serialized_start=1471
  _DOCKERENV._serialized_end=1609
  _PYTHONENV._serialized_start=1611
  _PYTHONENV._serialized_end=1735
  _CPURESOURCES._serialized_start=1737
  _CPURESOURCES._serialized_end=1847
  _GPURESOURCES._serialized_start=1849
  _GPURESOURCES._serialized_end=1936
  _DATATABLEDEFINITION._serialized_start=1939
  _DATATABLEDEFINITION._serialized_end=2084
  _DATACOLUMNDEFINITION._serialized_start=2086
  _DATACOLUMNDEFINITION._serialized_end=2178
  _DATAFORMAT._serialized_start=2180
  _DATAFORMAT._serialized_end=2254
  _CSVFORMAT._serialized_start=2256
  _CSVFORMAT._serialized_end=2327
  _BUILDINITIATOR._serialized_start=2330
  _BUILDINITIATOR._serialized_end=2495
  _USERBUILDINITIATOR._serialized_start=2497
  _USERBUILDINITIATOR._serialized_end=2517
  _AUTOMATIONBUILDINITIATOR._serialized_start=2519
  _AUTOMATIONBUILDINITIATOR._serialized_end=2615
# @@protoc_insertion_point(module_scope)
