# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/account/v1/account_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.account.v1 import account_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_account__pb2
from _qwak_proto.qwak.administration.account.v1 import preferences_pb2 as qwak_dot_administration_dot_account_dot_v1_dot_preferences__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4qwak/administration/account/v1/account_service.proto\x12\x1eqwak.administration.account.v1\x1a,qwak/administration/account/v1/account.proto\x1a\x30qwak/administration/account/v1/preferences.proto\"\xe8\x01\n\x14\x43reateAccountRequest\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x01 \x01(\t\x12\x44\n\x0bpreferences\x18\x02 \x01(\x0b\x32/.qwak.administration.account.AccountPreferences\x12\x39\n\x04type\x18\x03 \x01(\x0e\x32+.qwak.administration.account.v1.AccountType\x12\x39\n\x04tier\x18\x04 \x01(\x0e\x32+.qwak.administration.account.v1.AccountTier\"Q\n\x15\x43reateAccountResponse\x12\x38\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\'.qwak.administration.account.v1.Account\"\'\n\x11GetAccountRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\"N\n\x12GetAccountResponse\x12\x38\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\'.qwak.administration.account.v1.Account\"X\n\x13ListAccountsRequest\x12\x41\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x31.qwak.administration.account.v1.ListAccountFilter\"Q\n\x14ListAccountsResponse\x12\x39\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\'.qwak.administration.account.v1.Account\"\xe6\x01\n\x14UpdateAccountRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x44\n\x0bpreferences\x18\x02 \x01(\x0b\x32/.qwak.administration.account.AccountPreferences\x12\x39\n\x04type\x18\x03 \x01(\x0e\x32+.qwak.administration.account.v1.AccountType\x12\x39\n\x04tier\x18\x04 \x01(\x0e\x32+.qwak.administration.account.v1.AccountTier\"\x17\n\x15UpdateAccountResponse\"{\n\x1fUpdateAccountPreferencesRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x44\n\x0bpreferences\x18\x02 \x01(\x0b\x32/.qwak.administration.account.AccountPreferences\"\"\n UpdateAccountPreferencesResponse\"z\n\x15\x41\x64\x64\x41utoBindingRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12M\n\x14\x61uto_binding_account\x18\x02 \x03(\x0b\x32/.qwak.administration.account.v1.AutoBindingRule\"j\n\x16\x41\x64\x64\x41utoBindingResponse\x12P\n\x14\x61uto_binding_account\x18\x01 \x03(\x0b\x32\x32.qwak.administration.account.v1.AutoBindingAccount\"Q\n\x18RemoveAutoBindingRequest\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12!\n\x19\x61uto_binding_id_to_remove\x18\x02 \x03(\t\"\x1b\n\x19RemoveAutoBindingResponse2\xa8\x07\n\x0e\x41\x63\x63ountService\x12|\n\rCreateAccount\x12\x34.qwak.administration.account.v1.CreateAccountRequest\x1a\x35.qwak.administration.account.v1.CreateAccountResponse\x12s\n\nGetAccount\x12\x31.qwak.administration.account.v1.GetAccountRequest\x1a\x32.qwak.administration.account.v1.GetAccountResponse\x12y\n\x0cListAccounts\x12\x33.qwak.administration.account.v1.ListAccountsRequest\x1a\x34.qwak.administration.account.v1.ListAccountsResponse\x12|\n\rUpdateAccount\x12\x34.qwak.administration.account.v1.UpdateAccountRequest\x1a\x35.qwak.administration.account.v1.UpdateAccountResponse\x12\x9d\x01\n\x18UpdateAccountPreferences\x12?.qwak.administration.account.v1.UpdateAccountPreferencesRequest\x1a@.qwak.administration.account.v1.UpdateAccountPreferencesResponse\x12\x7f\n\x0e\x41\x64\x64\x41utoBinding\x12\x35.qwak.administration.account.v1.AddAutoBindingRequest\x1a\x36.qwak.administration.account.v1.AddAutoBindingResponse\x12\x88\x01\n\x11RemoveAutoBinding\x12\x38.qwak.administration.account.v1.RemoveAutoBindingRequest\x1a\x39.qwak.administration.account.v1.RemoveAutoBindingResponseB\xb4\x01\n)com.qwak.ai.administration.api.account.v1P\x01Z\x84\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/account/v1;account_v0b\x06proto3')



_CREATEACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['CreateAccountRequest']
_CREATEACCOUNTRESPONSE = DESCRIPTOR.message_types_by_name['CreateAccountResponse']
_GETACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['GetAccountRequest']
_GETACCOUNTRESPONSE = DESCRIPTOR.message_types_by_name['GetAccountResponse']
_LISTACCOUNTSREQUEST = DESCRIPTOR.message_types_by_name['ListAccountsRequest']
_LISTACCOUNTSRESPONSE = DESCRIPTOR.message_types_by_name['ListAccountsResponse']
_UPDATEACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['UpdateAccountRequest']
_UPDATEACCOUNTRESPONSE = DESCRIPTOR.message_types_by_name['UpdateAccountResponse']
_UPDATEACCOUNTPREFERENCESREQUEST = DESCRIPTOR.message_types_by_name['UpdateAccountPreferencesRequest']
_UPDATEACCOUNTPREFERENCESRESPONSE = DESCRIPTOR.message_types_by_name['UpdateAccountPreferencesResponse']
_ADDAUTOBINDINGREQUEST = DESCRIPTOR.message_types_by_name['AddAutoBindingRequest']
_ADDAUTOBINDINGRESPONSE = DESCRIPTOR.message_types_by_name['AddAutoBindingResponse']
_REMOVEAUTOBINDINGREQUEST = DESCRIPTOR.message_types_by_name['RemoveAutoBindingRequest']
_REMOVEAUTOBINDINGRESPONSE = DESCRIPTOR.message_types_by_name['RemoveAutoBindingResponse']
CreateAccountRequest = _reflection.GeneratedProtocolMessageType('CreateAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTREQUEST,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.CreateAccountRequest)
  })
_sym_db.RegisterMessage(CreateAccountRequest)

CreateAccountResponse = _reflection.GeneratedProtocolMessageType('CreateAccountResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTRESPONSE,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.CreateAccountResponse)
  })
_sym_db.RegisterMessage(CreateAccountResponse)

GetAccountRequest = _reflection.GeneratedProtocolMessageType('GetAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTREQUEST,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.GetAccountRequest)
  })
_sym_db.RegisterMessage(GetAccountRequest)

GetAccountResponse = _reflection.GeneratedProtocolMessageType('GetAccountResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTRESPONSE,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.GetAccountResponse)
  })
_sym_db.RegisterMessage(GetAccountResponse)

ListAccountsRequest = _reflection.GeneratedProtocolMessageType('ListAccountsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCOUNTSREQUEST,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.ListAccountsRequest)
  })
_sym_db.RegisterMessage(ListAccountsRequest)

ListAccountsResponse = _reflection.GeneratedProtocolMessageType('ListAccountsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCOUNTSRESPONSE,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.ListAccountsResponse)
  })
_sym_db.RegisterMessage(ListAccountsResponse)

UpdateAccountRequest = _reflection.GeneratedProtocolMessageType('UpdateAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEACCOUNTREQUEST,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.UpdateAccountRequest)
  })
_sym_db.RegisterMessage(UpdateAccountRequest)

UpdateAccountResponse = _reflection.GeneratedProtocolMessageType('UpdateAccountResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEACCOUNTRESPONSE,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.UpdateAccountResponse)
  })
_sym_db.RegisterMessage(UpdateAccountResponse)

UpdateAccountPreferencesRequest = _reflection.GeneratedProtocolMessageType('UpdateAccountPreferencesRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEACCOUNTPREFERENCESREQUEST,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.UpdateAccountPreferencesRequest)
  })
_sym_db.RegisterMessage(UpdateAccountPreferencesRequest)

UpdateAccountPreferencesResponse = _reflection.GeneratedProtocolMessageType('UpdateAccountPreferencesResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEACCOUNTPREFERENCESRESPONSE,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.UpdateAccountPreferencesResponse)
  })
_sym_db.RegisterMessage(UpdateAccountPreferencesResponse)

AddAutoBindingRequest = _reflection.GeneratedProtocolMessageType('AddAutoBindingRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDAUTOBINDINGREQUEST,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.AddAutoBindingRequest)
  })
_sym_db.RegisterMessage(AddAutoBindingRequest)

AddAutoBindingResponse = _reflection.GeneratedProtocolMessageType('AddAutoBindingResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDAUTOBINDINGRESPONSE,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.AddAutoBindingResponse)
  })
_sym_db.RegisterMessage(AddAutoBindingResponse)

RemoveAutoBindingRequest = _reflection.GeneratedProtocolMessageType('RemoveAutoBindingRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEAUTOBINDINGREQUEST,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.RemoveAutoBindingRequest)
  })
_sym_db.RegisterMessage(RemoveAutoBindingRequest)

RemoveAutoBindingResponse = _reflection.GeneratedProtocolMessageType('RemoveAutoBindingResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEAUTOBINDINGRESPONSE,
  '__module__' : 'qwak.administration.account.v1.account_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.account.v1.RemoveAutoBindingResponse)
  })
_sym_db.RegisterMessage(RemoveAutoBindingResponse)

_ACCOUNTSERVICE = DESCRIPTOR.services_by_name['AccountService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.qwak.ai.administration.api.account.v1P\001Z\204\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/account/v1;account_v0'
  _CREATEACCOUNTREQUEST._serialized_start=185
  _CREATEACCOUNTREQUEST._serialized_end=417
  _CREATEACCOUNTRESPONSE._serialized_start=419
  _CREATEACCOUNTRESPONSE._serialized_end=500
  _GETACCOUNTREQUEST._serialized_start=502
  _GETACCOUNTREQUEST._serialized_end=541
  _GETACCOUNTRESPONSE._serialized_start=543
  _GETACCOUNTRESPONSE._serialized_end=621
  _LISTACCOUNTSREQUEST._serialized_start=623
  _LISTACCOUNTSREQUEST._serialized_end=711
  _LISTACCOUNTSRESPONSE._serialized_start=713
  _LISTACCOUNTSRESPONSE._serialized_end=794
  _UPDATEACCOUNTREQUEST._serialized_start=797
  _UPDATEACCOUNTREQUEST._serialized_end=1027
  _UPDATEACCOUNTRESPONSE._serialized_start=1029
  _UPDATEACCOUNTRESPONSE._serialized_end=1052
  _UPDATEACCOUNTPREFERENCESREQUEST._serialized_start=1054
  _UPDATEACCOUNTPREFERENCESREQUEST._serialized_end=1177
  _UPDATEACCOUNTPREFERENCESRESPONSE._serialized_start=1179
  _UPDATEACCOUNTPREFERENCESRESPONSE._serialized_end=1213
  _ADDAUTOBINDINGREQUEST._serialized_start=1215
  _ADDAUTOBINDINGREQUEST._serialized_end=1337
  _ADDAUTOBINDINGRESPONSE._serialized_start=1339
  _ADDAUTOBINDINGRESPONSE._serialized_end=1445
  _REMOVEAUTOBINDINGREQUEST._serialized_start=1447
  _REMOVEAUTOBINDINGREQUEST._serialized_end=1528
  _REMOVEAUTOBINDINGRESPONSE._serialized_start=1530
  _REMOVEAUTOBINDINGRESPONSE._serialized_end=1557
  _ACCOUNTSERVICE._serialized_start=1560
  _ACCOUNTSERVICE._serialized_end=2496
# @@protoc_insertion_point(module_scope)
