"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class BuildSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_REPOSITORY_SETTING_FIELD_NUMBER: builtins.int
    @property
    def model_repository_setting(self) -> global___ModelRepositorySettings: ...
    def __init__(
        self,
        *,
        model_repository_setting: global___ModelRepositorySettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model_repository_setting", b"model_repository_setting"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_repository_setting", b"model_repository_setting"]) -> None: ...

global___BuildSettings = BuildSettings

class ModelRepositorySettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_REGISTRY_PREFIX_FIELD_NUMBER: builtins.int
    REPOSITORY_SETTINGS_ECR_FIELD_NUMBER: builtins.int
    REPOSITORY_SETTINGS_JFROG_FIELD_NUMBER: builtins.int
    REPOSITORY_SETTINGS_GCR_FIELD_NUMBER: builtins.int
    container_registry_prefix: builtins.str
    @property
    def repository_settings_ecr(self) -> global___RepositorySettingsECR: ...
    @property
    def repository_settings_jfrog(self) -> global___RepositorySettingsJFrog: ...
    @property
    def repository_settings_gcr(self) -> global___RepositorySettingsGCR: ...
    def __init__(
        self,
        *,
        container_registry_prefix: builtins.str = ...,
        repository_settings_ecr: global___RepositorySettingsECR | None = ...,
        repository_settings_jfrog: global___RepositorySettingsJFrog | None = ...,
        repository_settings_gcr: global___RepositorySettingsGCR | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["repository_settings_ecr", b"repository_settings_ecr", "repository_settings_gcr", b"repository_settings_gcr", "repository_settings_jfrog", b"repository_settings_jfrog", "repository_type", b"repository_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_registry_prefix", b"container_registry_prefix", "repository_settings_ecr", b"repository_settings_ecr", "repository_settings_gcr", b"repository_settings_gcr", "repository_settings_jfrog", b"repository_settings_jfrog", "repository_type", b"repository_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["repository_type", b"repository_type"]) -> typing_extensions.Literal["repository_settings_ecr", "repository_settings_jfrog", "repository_settings_gcr"] | None: ...

global___ModelRepositorySettings = ModelRepositorySettings

class RepositorySettingsJFrog(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHENTICATION_SETTINGS_FIELD_NUMBER: builtins.int
    JFROG_PROJECT_NAME_FIELD_NUMBER: builtins.int
    EXTERNAL_REPOSITORY_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def authentication_settings(self) -> global___AuthenticationSettings: ...
    jfrog_project_name: builtins.str
    @property
    def external_repository_settings(self) -> global___ExternalRepositorySettings:
        """Setting for external repositories to be used during the build"""
    def __init__(
        self,
        *,
        authentication_settings: global___AuthenticationSettings | None = ...,
        jfrog_project_name: builtins.str = ...,
        external_repository_settings: global___ExternalRepositorySettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authentication_settings", b"authentication_settings", "external_repository_settings", b"external_repository_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_settings", b"authentication_settings", "external_repository_settings", b"external_repository_settings", "jfrog_project_name", b"jfrog_project_name"]) -> None: ...

global___RepositorySettingsJFrog = RepositorySettingsJFrog

class ExternalRepositorySettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PYTHON_REPOSITORY_FIELD_NUMBER: builtins.int
    HUGGINGFACE_REPOSITORY_FIELD_NUMBER: builtins.int
    ALLOW_EXTERNAL_PYTHON_REPOSITORIES_FIELD_NUMBER: builtins.int
    VIRTUAL_PYTHON_DEPENDENCIES_REPOSITORY_FIELD_NUMBER: builtins.int
    @property
    def python_repository(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """A list of private python repositories to be used by the build"""
    huggingface_repository: builtins.str
    """A HuggingFace remote proxy to be used by the build"""
    allow_external_python_repositories: builtins.bool
    """Allow external python repositories to be used"""
    virtual_python_dependencies_repository: builtins.str
    """The virtual python repository to use"""
    def __init__(
        self,
        *,
        python_repository: collections.abc.Iterable[builtins.str] | None = ...,
        huggingface_repository: builtins.str = ...,
        allow_external_python_repositories: builtins.bool = ...,
        virtual_python_dependencies_repository: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_external_python_repositories", b"allow_external_python_repositories", "huggingface_repository", b"huggingface_repository", "python_repository", b"python_repository", "virtual_python_dependencies_repository", b"virtual_python_dependencies_repository"]) -> None: ...

global___ExternalRepositorySettings = ExternalRepositorySettings

class AuthenticationSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    token: builtins.str
    username: builtins.str
    def __init__(
        self,
        *,
        token: builtins.str = ...,
        username: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["token", b"token", "username", b"username"]) -> None: ...

global___AuthenticationSettings = AuthenticationSettings

class RepositorySettingsECR(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RepositorySettingsECR = RepositorySettingsECR

class RepositorySettingsGCR(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RepositorySettingsGCR = RepositorySettingsGCR
