# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/sources/data_source.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.feature_store.sources import batch_pb2 as qwak_dot_feature__store_dot_sources_dot_batch__pb2
from _qwak_proto.qwak.feature_store.sources import streaming_pb2 as qwak_dot_feature__store_dot_sources_dot_streaming__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/feature_store/sources/data_source.proto\x12\x1aqwak.feature.store.sources\x1a\x1fgoogle/protobuf/timestamp.proto\x1a&qwak/feature_store/sources/batch.proto\x1a*qwak/feature_store/sources/streaming.proto\"\xe3\x01\n\nDataSource\x12P\n\x16\x64\x61ta_source_definition\x18\x01 \x01(\x0b\x32\x30.qwak.feature.store.sources.DataSourceDefinition\x12@\n\x08metadata\x18\x02 \x01(\x0b\x32..qwak.feature.store.sources.DataSourceMetadata\x12\x41\n\x0c\x66\x65\x61ture_sets\x18\x03 \x03(\x0b\x32+.qwak.feature.store.sources.FeatureSetBrief\"t\n\x14\x44\x61taSourceDefinition\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x44\n\x10\x64\x61ta_source_spec\x18\x02 \x01(\x0b\x32*.qwak.feature.store.sources.DataSourceSpec\"\xa8\x01\n\x12\x44\x61taSourceMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\t\x12\x34\n\x10last_modified_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x04 \x01(\t\"\x9f\x01\n\x0e\x44\x61taSourceSpec\x12?\n\x0c\x62\x61tch_source\x18\x01 \x01(\x0b\x32\'.qwak.feature.store.sources.BatchSourceH\x00\x12\x44\n\rstream_source\x18\x02 \x01(\x0b\x32+.qwak.feature.store.sources.StreamingSourceH\x00\x42\x06\n\x04type\"]\n\x0f\x46\x65\x61tureSetBrief\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_type\x18\x03 \x01(\x05\x42X\n%com.qwak.ai.feature.store.sources.apiP\x01Z-qwak/featurestore/sources;featurestoresourcesb\x06proto3')



_DATASOURCE = DESCRIPTOR.message_types_by_name['DataSource']
_DATASOURCEDEFINITION = DESCRIPTOR.message_types_by_name['DataSourceDefinition']
_DATASOURCEMETADATA = DESCRIPTOR.message_types_by_name['DataSourceMetadata']
_DATASOURCESPEC = DESCRIPTOR.message_types_by_name['DataSourceSpec']
_FEATURESETBRIEF = DESCRIPTOR.message_types_by_name['FeatureSetBrief']
DataSource = _reflection.GeneratedProtocolMessageType('DataSource', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCE,
  '__module__' : 'qwak.feature_store.sources.data_source_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.DataSource)
  })
_sym_db.RegisterMessage(DataSource)

DataSourceDefinition = _reflection.GeneratedProtocolMessageType('DataSourceDefinition', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEDEFINITION,
  '__module__' : 'qwak.feature_store.sources.data_source_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.DataSourceDefinition)
  })
_sym_db.RegisterMessage(DataSourceDefinition)

DataSourceMetadata = _reflection.GeneratedProtocolMessageType('DataSourceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEMETADATA,
  '__module__' : 'qwak.feature_store.sources.data_source_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.DataSourceMetadata)
  })
_sym_db.RegisterMessage(DataSourceMetadata)

DataSourceSpec = _reflection.GeneratedProtocolMessageType('DataSourceSpec', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESPEC,
  '__module__' : 'qwak.feature_store.sources.data_source_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.DataSourceSpec)
  })
_sym_db.RegisterMessage(DataSourceSpec)

FeatureSetBrief = _reflection.GeneratedProtocolMessageType('FeatureSetBrief', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETBRIEF,
  '__module__' : 'qwak.feature_store.sources.data_source_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.sources.FeatureSetBrief)
  })
_sym_db.RegisterMessage(FeatureSetBrief)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.feature.store.sources.apiP\001Z-qwak/featurestore/sources;featurestoresources'
  _DATASOURCE._serialized_start=194
  _DATASOURCE._serialized_end=421
  _DATASOURCEDEFINITION._serialized_start=423
  _DATASOURCEDEFINITION._serialized_end=539
  _DATASOURCEMETADATA._serialized_start=542
  _DATASOURCEMETADATA._serialized_end=710
  _DATASOURCESPEC._serialized_start=713
  _DATASOURCESPEC._serialized_end=872
  _FEATURESETBRIEF._serialized_start=874
  _FEATURESETBRIEF._serialized_end=967
# @@protoc_insertion_point(module_scope)
