# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/execution_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.execution.v1 import backfill_pb2 as qwak_dot_execution_dot_v1_dot_backfill__pb2
from _qwak_proto.qwak.execution.v1 import batch_pb2 as qwak_dot_execution_dot_v1_dot_batch__pb2
from _qwak_proto.qwak.execution.v1 import deletion_pb2 as qwak_dot_execution_dot_v1_dot_deletion__pb2
from _qwak_proto.qwak.execution.v1 import execution_pb2 as qwak_dot_execution_dot_v1_dot_execution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)qwak/execution/v1/execution_service.proto\x12\x1fqwak.feature.store.execution.v1\x1a qwak/execution/v1/backfill.proto\x1a\x1dqwak/execution/v1/batch.proto\x1a qwak/execution/v1/deletion.proto\x1a!qwak/execution/v1/execution.proto\"^\n\x16TriggerBackfillRequest\x12\x44\n\rbackfill_spec\x18\x01 \x01(\x0b\x32-.qwak.feature.store.execution.v1.BackfillSpec\"/\n\x17TriggerBackfillResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"1\n\x19GetExecutionStatusRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"h\n\x1aGetExecutionStatusResponse\x12J\n\x10\x65xecution_status\x18\x01 \x01(\x0e\x32\x30.qwak.feature.store.execution.v1.ExecutionStatus\"0\n\x18GetExecutionEntryRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"e\n\x19GetExecutionEntryResponse\x12H\n\x0f\x65xecution_entry\x18\x01 \x01(\x0b\x32/.qwak.feature.store.execution.v1.ExecutionEntry\"i\n\x1dTriggerBatchFeaturesetRequest\x12H\n\x0f\x62\x61tch_ingestion\x18\x01 \x01(\x0b\x32/.qwak.feature.store.execution.v1.BatchIngestion\"6\n\x1eTriggerBatchFeaturesetResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\":\n!GetRunningExecutionEntriesRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\"p\n\"GetRunningExecutionEntriesResponse\x12J\n\x11\x65xecution_entries\x18\x01 \x03(\x0b\x32/.qwak.feature.store.execution.v1.ExecutionEntry\"9\n TriggerFeaturesetDeletionRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\"9\n!TriggerFeaturesetDeletionResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"<\n#InitPaginationByFeaturesetIdRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\"Y\n$InitPaginationByFeaturesetIdResponse\x12\x14\n\x0crecord_count\x18\x01 \x01(\x03\x12\x1b\n\x13max_execution_index\x18\x02 \x01(\x03\"\x81\x01\n#ListExecutionsByFeaturesetIdRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x13\n\x0bpage_number\x18\x03 \x01(\x05\x12\x1b\n\x13max_execution_index\x18\x04 \x01(\x03\"r\n$ListExecutionsByFeaturesetIdResponse\x12J\n\x11\x65xecution_entries\x18\x01 \x03(\x0b\x32/.qwak.feature.store.execution.v1.ExecutionEntry2\x8c\n\n\x1c\x46\x65\x61tureStoreExecutionService\x12\x89\x01\n\x14TriggerBatchBackfill\x12\x37.qwak.feature.store.execution.v1.TriggerBackfillRequest\x1a\x38.qwak.feature.store.execution.v1.TriggerBackfillResponse\x12\x99\x01\n\x16TriggerBatchFeatureset\x12>.qwak.feature.store.execution.v1.TriggerBatchFeaturesetRequest\x1a?.qwak.feature.store.execution.v1.TriggerBatchFeaturesetResponse\x12\xa2\x01\n\x19TriggerFeaturesetDeletion\x12\x41.qwak.feature.store.execution.v1.TriggerFeaturesetDeletionRequest\x1a\x42.qwak.feature.store.execution.v1.TriggerFeaturesetDeletionResponse\x12\x8d\x01\n\x12GetExecutionStatus\x12:.qwak.feature.store.execution.v1.GetExecutionStatusRequest\x1a;.qwak.feature.store.execution.v1.GetExecutionStatusResponse\x12\x8a\x01\n\x11GetExecutionEntry\x12\x39.qwak.feature.store.execution.v1.GetExecutionEntryRequest\x1a:.qwak.feature.store.execution.v1.GetExecutionEntryResponse\x12\xa5\x01\n\x1aGetRunningExecutionEntries\x12\x42.qwak.feature.store.execution.v1.GetRunningExecutionEntriesRequest\x1a\x43.qwak.feature.store.execution.v1.GetRunningExecutionEntriesResponse\x12\xab\x01\n\x1cInitPaginationByFeaturesetId\x12\x44.qwak.feature.store.execution.v1.InitPaginationByFeaturesetIdRequest\x1a\x45.qwak.feature.store.execution.v1.InitPaginationByFeaturesetIdResponse\x12\xab\x01\n\x1cListExecutionsByFeaturesetId\x12\x44.qwak.feature.store.execution.v1.ListExecutionsByFeaturesetIdRequest\x1a\x45.qwak.feature.store.execution.v1.ListExecutionsByFeaturesetIdResponseB)\n%com.qwak.ai.features.execution.api.v1P\x01\x62\x06proto3')



_TRIGGERBACKFILLREQUEST = DESCRIPTOR.message_types_by_name['TriggerBackfillRequest']
_TRIGGERBACKFILLRESPONSE = DESCRIPTOR.message_types_by_name['TriggerBackfillResponse']
_GETEXECUTIONSTATUSREQUEST = DESCRIPTOR.message_types_by_name['GetExecutionStatusRequest']
_GETEXECUTIONSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['GetExecutionStatusResponse']
_GETEXECUTIONENTRYREQUEST = DESCRIPTOR.message_types_by_name['GetExecutionEntryRequest']
_GETEXECUTIONENTRYRESPONSE = DESCRIPTOR.message_types_by_name['GetExecutionEntryResponse']
_TRIGGERBATCHFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['TriggerBatchFeaturesetRequest']
_TRIGGERBATCHFEATURESETRESPONSE = DESCRIPTOR.message_types_by_name['TriggerBatchFeaturesetResponse']
_GETRUNNINGEXECUTIONENTRIESREQUEST = DESCRIPTOR.message_types_by_name['GetRunningExecutionEntriesRequest']
_GETRUNNINGEXECUTIONENTRIESRESPONSE = DESCRIPTOR.message_types_by_name['GetRunningExecutionEntriesResponse']
_TRIGGERFEATURESETDELETIONREQUEST = DESCRIPTOR.message_types_by_name['TriggerFeaturesetDeletionRequest']
_TRIGGERFEATURESETDELETIONRESPONSE = DESCRIPTOR.message_types_by_name['TriggerFeaturesetDeletionResponse']
_INITPAGINATIONBYFEATURESETIDREQUEST = DESCRIPTOR.message_types_by_name['InitPaginationByFeaturesetIdRequest']
_INITPAGINATIONBYFEATURESETIDRESPONSE = DESCRIPTOR.message_types_by_name['InitPaginationByFeaturesetIdResponse']
_LISTEXECUTIONSBYFEATURESETIDREQUEST = DESCRIPTOR.message_types_by_name['ListExecutionsByFeaturesetIdRequest']
_LISTEXECUTIONSBYFEATURESETIDRESPONSE = DESCRIPTOR.message_types_by_name['ListExecutionsByFeaturesetIdResponse']
TriggerBackfillRequest = _reflection.GeneratedProtocolMessageType('TriggerBackfillRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGERBACKFILLREQUEST,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.TriggerBackfillRequest)
  })
_sym_db.RegisterMessage(TriggerBackfillRequest)

TriggerBackfillResponse = _reflection.GeneratedProtocolMessageType('TriggerBackfillResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGERBACKFILLRESPONSE,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.TriggerBackfillResponse)
  })
_sym_db.RegisterMessage(TriggerBackfillResponse)

GetExecutionStatusRequest = _reflection.GeneratedProtocolMessageType('GetExecutionStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEXECUTIONSTATUSREQUEST,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.GetExecutionStatusRequest)
  })
_sym_db.RegisterMessage(GetExecutionStatusRequest)

GetExecutionStatusResponse = _reflection.GeneratedProtocolMessageType('GetExecutionStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETEXECUTIONSTATUSRESPONSE,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.GetExecutionStatusResponse)
  })
_sym_db.RegisterMessage(GetExecutionStatusResponse)

GetExecutionEntryRequest = _reflection.GeneratedProtocolMessageType('GetExecutionEntryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEXECUTIONENTRYREQUEST,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.GetExecutionEntryRequest)
  })
_sym_db.RegisterMessage(GetExecutionEntryRequest)

GetExecutionEntryResponse = _reflection.GeneratedProtocolMessageType('GetExecutionEntryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETEXECUTIONENTRYRESPONSE,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.GetExecutionEntryResponse)
  })
_sym_db.RegisterMessage(GetExecutionEntryResponse)

TriggerBatchFeaturesetRequest = _reflection.GeneratedProtocolMessageType('TriggerBatchFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGERBATCHFEATURESETREQUEST,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.TriggerBatchFeaturesetRequest)
  })
_sym_db.RegisterMessage(TriggerBatchFeaturesetRequest)

TriggerBatchFeaturesetResponse = _reflection.GeneratedProtocolMessageType('TriggerBatchFeaturesetResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGERBATCHFEATURESETRESPONSE,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.TriggerBatchFeaturesetResponse)
  })
_sym_db.RegisterMessage(TriggerBatchFeaturesetResponse)

GetRunningExecutionEntriesRequest = _reflection.GeneratedProtocolMessageType('GetRunningExecutionEntriesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRUNNINGEXECUTIONENTRIESREQUEST,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.GetRunningExecutionEntriesRequest)
  })
_sym_db.RegisterMessage(GetRunningExecutionEntriesRequest)

GetRunningExecutionEntriesResponse = _reflection.GeneratedProtocolMessageType('GetRunningExecutionEntriesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRUNNINGEXECUTIONENTRIESRESPONSE,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.GetRunningExecutionEntriesResponse)
  })
_sym_db.RegisterMessage(GetRunningExecutionEntriesResponse)

TriggerFeaturesetDeletionRequest = _reflection.GeneratedProtocolMessageType('TriggerFeaturesetDeletionRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGERFEATURESETDELETIONREQUEST,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.TriggerFeaturesetDeletionRequest)
  })
_sym_db.RegisterMessage(TriggerFeaturesetDeletionRequest)

TriggerFeaturesetDeletionResponse = _reflection.GeneratedProtocolMessageType('TriggerFeaturesetDeletionResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGERFEATURESETDELETIONRESPONSE,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.TriggerFeaturesetDeletionResponse)
  })
_sym_db.RegisterMessage(TriggerFeaturesetDeletionResponse)

InitPaginationByFeaturesetIdRequest = _reflection.GeneratedProtocolMessageType('InitPaginationByFeaturesetIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITPAGINATIONBYFEATURESETIDREQUEST,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.InitPaginationByFeaturesetIdRequest)
  })
_sym_db.RegisterMessage(InitPaginationByFeaturesetIdRequest)

InitPaginationByFeaturesetIdResponse = _reflection.GeneratedProtocolMessageType('InitPaginationByFeaturesetIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _INITPAGINATIONBYFEATURESETIDRESPONSE,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.InitPaginationByFeaturesetIdResponse)
  })
_sym_db.RegisterMessage(InitPaginationByFeaturesetIdResponse)

ListExecutionsByFeaturesetIdRequest = _reflection.GeneratedProtocolMessageType('ListExecutionsByFeaturesetIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTEXECUTIONSBYFEATURESETIDREQUEST,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.ListExecutionsByFeaturesetIdRequest)
  })
_sym_db.RegisterMessage(ListExecutionsByFeaturesetIdRequest)

ListExecutionsByFeaturesetIdResponse = _reflection.GeneratedProtocolMessageType('ListExecutionsByFeaturesetIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTEXECUTIONSBYFEATURESETIDRESPONSE,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.ListExecutionsByFeaturesetIdResponse)
  })
_sym_db.RegisterMessage(ListExecutionsByFeaturesetIdResponse)

_FEATURESTOREEXECUTIONSERVICE = DESCRIPTOR.services_by_name['FeatureStoreExecutionService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.features.execution.api.v1P\001'
  _TRIGGERBACKFILLREQUEST._serialized_start=212
  _TRIGGERBACKFILLREQUEST._serialized_end=306
  _TRIGGERBACKFILLRESPONSE._serialized_start=308
  _TRIGGERBACKFILLRESPONSE._serialized_end=355
  _GETEXECUTIONSTATUSREQUEST._serialized_start=357
  _GETEXECUTIONSTATUSREQUEST._serialized_end=406
  _GETEXECUTIONSTATUSRESPONSE._serialized_start=408
  _GETEXECUTIONSTATUSRESPONSE._serialized_end=512
  _GETEXECUTIONENTRYREQUEST._serialized_start=514
  _GETEXECUTIONENTRYREQUEST._serialized_end=562
  _GETEXECUTIONENTRYRESPONSE._serialized_start=564
  _GETEXECUTIONENTRYRESPONSE._serialized_end=665
  _TRIGGERBATCHFEATURESETREQUEST._serialized_start=667
  _TRIGGERBATCHFEATURESETREQUEST._serialized_end=772
  _TRIGGERBATCHFEATURESETRESPONSE._serialized_start=774
  _TRIGGERBATCHFEATURESETRESPONSE._serialized_end=828
  _GETRUNNINGEXECUTIONENTRIESREQUEST._serialized_start=830
  _GETRUNNINGEXECUTIONENTRIESREQUEST._serialized_end=888
  _GETRUNNINGEXECUTIONENTRIESRESPONSE._serialized_start=890
  _GETRUNNINGEXECUTIONENTRIESRESPONSE._serialized_end=1002
  _TRIGGERFEATURESETDELETIONREQUEST._serialized_start=1004
  _TRIGGERFEATURESETDELETIONREQUEST._serialized_end=1061
  _TRIGGERFEATURESETDELETIONRESPONSE._serialized_start=1063
  _TRIGGERFEATURESETDELETIONRESPONSE._serialized_end=1120
  _INITPAGINATIONBYFEATURESETIDREQUEST._serialized_start=1122
  _INITPAGINATIONBYFEATURESETIDREQUEST._serialized_end=1182
  _INITPAGINATIONBYFEATURESETIDRESPONSE._serialized_start=1184
  _INITPAGINATIONBYFEATURESETIDRESPONSE._serialized_end=1273
  _LISTEXECUTIONSBYFEATURESETIDREQUEST._serialized_start=1276
  _LISTEXECUTIONSBYFEATURESETIDREQUEST._serialized_end=1405
  _LISTEXECUTIONSBYFEATURESETIDRESPONSE._serialized_start=1407
  _LISTEXECUTIONSBYFEATURESETIDRESPONSE._serialized_end=1521
  _FEATURESTOREEXECUTIONSERVICE._serialized_start=1524
  _FEATURESTOREEXECUTIONSERVICE._serialized_end=2816
# @@protoc_insertion_point(module_scope)
