"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.deployment.alert_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetAlertsConfigurationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BRANCH_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model id get alerts for"""
    branch_id: builtins.str
    """The branch id get alerts for"""
    environment_id: builtins.str
    """The environment id to save alerts."""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        branch_id: builtins.str = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_id", b"branch_id", "environment_id", b"environment_id", "model_id", b"model_id"]) -> None: ...

global___GetAlertsConfigurationRequest = GetAlertsConfigurationRequest

class GetAlertsConfigurationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALERTS_FIELD_NUMBER: builtins.int
    @property
    def alerts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.deployment.alert_pb2.AlertRule]:
        """The saved alerts for the model"""
    def __init__(
        self,
        *,
        alerts: collections.abc.Iterable[qwak.deployment.alert_pb2.AlertRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["alerts", b"alerts"]) -> None: ...

global___GetAlertsConfigurationResponse = GetAlertsConfigurationResponse

class ApplyAlertsConfigurationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BRANCH_ID_FIELD_NUMBER: builtins.int
    ALERTS_FIELD_NUMBER: builtins.int
    MODEL_UUID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """Model named ID, which will be used as a routing key for the model"""
    branch_id: builtins.str
    """Branch ID to deploy the model under"""
    @property
    def alerts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.deployment.alert_pb2.AlertRule]:
        """The alerts list for model"""
    model_uuid: builtins.str
    """Model UUID uses to show deployments of model."""
    environment_id: builtins.str
    """Environment to apply alerts"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        branch_id: builtins.str = ...,
        alerts: collections.abc.Iterable[qwak.deployment.alert_pb2.AlertRule] | None = ...,
        model_uuid: builtins.str = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["alerts", b"alerts", "branch_id", b"branch_id", "environment_id", b"environment_id", "model_id", b"model_id", "model_uuid", b"model_uuid"]) -> None: ...

global___ApplyAlertsConfigurationRequest = ApplyAlertsConfigurationRequest

class ApplyAlertsConfigurationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ApplyAlertsConfigurationResponse = ApplyAlertsConfigurationResponse

class GetNotificationChannelsListRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """Environment to get notification for"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id"]) -> None: ...

global___GetNotificationChannelsListRequest = GetNotificationChannelsListRequest

class GetNotificationChannelsListResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTIFICATION_CHANNELS_FIELD_NUMBER: builtins.int
    @property
    def notification_channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.deployment.alert_pb2.NotificationChannelSpec]:
        """The Notification Channels exist"""
    def __init__(
        self,
        *,
        notification_channels: collections.abc.Iterable[qwak.deployment.alert_pb2.NotificationChannelSpec] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["notification_channels", b"notification_channels"]) -> None: ...

global___GetNotificationChannelsListResponse = GetNotificationChannelsListResponse

class ApplyNotificationChannelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTIFICATION_CHANNEL_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    @property
    def notification_channel(self) -> qwak.deployment.alert_pb2.NotificationChannel:
        """The Notification channel to add"""
    environment_id: builtins.str
    """Environment to apply notification channels"""
    def __init__(
        self,
        *,
        notification_channel: qwak.deployment.alert_pb2.NotificationChannel | None = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["notification_channel", b"notification_channel"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "notification_channel", b"notification_channel"]) -> None: ...

global___ApplyNotificationChannelRequest = ApplyNotificationChannelRequest

class ApplyNotificationChannelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ApplyNotificationChannelResponse = ApplyNotificationChannelResponse

class DeleteNotificationChannelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTIFICATION_CHANNEL_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    notification_channel_id: builtins.str
    """Notification channel id to delete"""
    environment_id: builtins.str
    """Environment to delete it from"""
    def __init__(
        self,
        *,
        notification_channel_id: builtins.str = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "notification_channel_id", b"notification_channel_id"]) -> None: ...

global___DeleteNotificationChannelRequest = DeleteNotificationChannelRequest

class DeleteNotificationChannelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteNotificationChannelResponse = DeleteNotificationChannelResponse

class GetNotificationChannelDetailsListRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """Environment to get notification details list for"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id"]) -> None: ...

global___GetNotificationChannelDetailsListRequest = GetNotificationChannelDetailsListRequest

class GetNotificationChannelDetailsListResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTIFICATION_CHANNELS_FIELD_NUMBER: builtins.int
    @property
    def notification_channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.deployment.alert_pb2.NotificationChannel]:
        """The channels saved"""
    def __init__(
        self,
        *,
        notification_channels: collections.abc.Iterable[qwak.deployment.alert_pb2.NotificationChannel] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["notification_channels", b"notification_channels"]) -> None: ...

global___GetNotificationChannelDetailsListResponse = GetNotificationChannelDetailsListResponse
